from xhs_spider.xhs_utils.xhs_util import *

class Profile:
    def __init__(self):
        self.cookies = check_cookies()

    # 个人信息主页
    def get_profile_info(self, url):
        headers = get_headers()
        response = requests.get(url, headers=headers, cookies=self.cookies)
        html_text = response.text
        userId = url.split('/')[-1]
        profile = handle_profile_info(userId, html_text)
        return profile

    def save_profile_info(self, url):
        profile = self.get_profile_info(url)
        print(f'开始保存用户{profile.nickname}基本信息')
        userId = profile.userId
        nickname = norm_str(profile.nickname)
        path = f'./datas/{nickname}_{userId}'
        check_and_create_path(path)
        download_media(path, 'avatar', profile.avatar, 'image', '用户头像')
        save_user_detail(path, profile)
        print(f'User {nickname} 信息保存成功')
        return profile


    def main(self, user_url_list):
        # user_url_list = [
        #     'https://www.xiaohongshu.com/user/profile/59d44fd66eea883eff45747f',
        #     'https://www.xiaohongshu.com/user/profile/6185ce66000000001000705b',
        # ]
        for url in user_url_list:
            try:
                self.save_profile_info(url)
            except:
                print(f'user {url} 查询失败')


if __name__ == '__main__':
    profile = Profile()
    user_url_list = [
        'https://www.xiaohongshu.com/user/profile/59d44fd66eea883eff45747f',
        'https://www.xiaohongshu.com/user/profile/6185ce66000000001000705b',
    ]
    profile.main(user_url_list)


class Note_Detail():
    def __init__(self, id, note_id, note_type, user_id, nickname, avatar, title, desc, liked_count, collected_count, comment_count, share_count, video_addr, image_list, tag_list, upload_time, ip_location):
        self.id = id
        self.note_id = note_id
        self.note_type = note_type
        self.user_id = user_id
        self.nickname = nickname
        self.avatar = avatar
        self.title = title
        self.desc = desc
        self.liked_count = liked_count
        self.collected_count = collected_count
        self.comment_count = comment_count
        self.share_count = share_count
        self.video_addr = video_addr
        self.image_list = image_list
        self.tag_list = tag_list
        self.upload_time = upload_time
        self.ip_location = ip_location

    def __str__(self):
        # 每个值都要换行
        return f'id: {self.id}\n' \
                f'note_id: {self.note_id}\n' \
                f'user_id: {self.user_id}\n' \
                f'nickname: {self.nickname}\n' \
                f'avatar: {self.avatar}\n' \
                f'title: {self.title}\n' \
                f'desc: {self.desc}\n' \
                f'liked_count: {self.liked_count}\n' \
                f'collected_count: {self.collected_count}\n' \
                f'comment_count: {self.comment_count}\n' \
                f'share_count: {self.share_count}\n' \
                f'video_addr: {self.video_addr}\n' \
                f'images: {self.image_list}\n' \
                f'tag_list: {self.tag_list}\n' \
                f'upload_time: {self.upload_time}\n' \
                f'note_ip_location: {self.ip_location}\n'


